@@ -275,7 +275,8 @@ class CAM(object):
             if msg['type'] == 'RUN' and self._node_status['node_status'] != "RUNNING":
                 task = msg['task']
                 self._log_queue[task['task_id']] = multiprocessing.Queue()
-                self.p = multiprocessing.Process(target = run_cmd, args = (prefix + task['cmd'] + suffix, self._log_queue[task['task_id']], get_node_name(), self._conf))
+                task['cmd'] = prefix + task['cmd'] + suffix
+                self.p = multiprocessing.Process(target = run_cmd, args = (task['cmd'], self._log_queue[task['task_id']], get_node_name(), self._conf))
                 self.p.start()
                 task['start_time'] = get_time()
                 task['node'] = get_node_name()
